@@ -46,6 +46,7 @@ class Client(object):
         self._password = password
         self._api_key = api_key
         self._logged_in = False
+        self._meta = {}
         if self._username and self._password:
             self._login()
 
@@ -72,6 +73,7 @@ class Client(object):
         data = self.login(self._username, self._password)
         if data.get('status_code') == 200:
             self._logged_in = True
+            self._meta = data.get('meta', {})
             self._api_key = data.get('meta', {}).get('api_key')
         else:
             raise ClientException(data.get('error', 'Login fail'))
